@@ -11,7 +11,7 @@ require Exporter;
 require AutoLoader;
 
 use vars qw($VERSION);
-$VERSION = "2.006.1";
+$VERSION = "2.001";
 
 use Fcntl qw(:DEFAULT :flock);
 
@@ -1090,7 +1090,6 @@ sub cond_evaluate {
 
   # first recursively evaluate according to parentheses
 
-  $debug and print STDERR " [cond_evaluate(): $cond]";
   defined $cond or return undef;
 
   # have we computed this condition all the way before?
@@ -1119,11 +1118,11 @@ sub cond_evaluate {
       while ($cond =~ /(^| |\()\(([^\)]+)\)/) {
 	  ($psc,$subcond) = ($1,$2);
 	  $rcond = $self->cond_evaluate($subcond,$ovr);
-	  $debug and print STDERR " [eval $subcond-> $rcond in $cond]";
+	  
+	  $debug and print STDERR " [eval $subcond -> $rcond]";
 	  #      $cond =~ s/($&)/$rcond/g;
-	  # fix in 2.005: Shouldn't have permitted active metachars here:
-	  $cond =~ s/\(\Q$subcond\E\)/$rcond/g;
-	  $debug and print STDERR " [reduced to $cond]";
+	  $cond =~ s/\($subcond\)/$rcond/g;
+	  #      substr($cond,pos($cond)-(length($subcond)+2),length($subcond)+2) = $rcond;
       }
       $debug and print STDERR " [simplified cond: $cond]"; 
       
@@ -1135,7 +1134,7 @@ sub cond_evaluate {
 		 ==|!=|<=>|<=|>=|<|>| (eq|ne|lt|le|gt|ge) |   # comparison binary ops
 
 		 \=~|\!~| x |\.|\+|\-|\*\*|\*| (mod|div) |\/)?/gmx) { # arithmetic and string ops
-	  $debug and print STDERR " [ conditional ($1,$2,$3,$4,$5,$6,$7,$8)]";
+#	  $debug and print STDERR " [ conditional ($1,$2,$3,$4,$5,$6,$7,$8)]";
 	  
 	  my ($unaryop,$operand,$binaryop) = ($1,$2,$4);
 #          print STDERR " [unaryop=",($unaryop || 'undef'),", calling ident_eval($operand)]";
@@ -1155,8 +1154,8 @@ sub cond_evaluate {
 	  }
 	  $binaryop and $binop_leftover=$binaryop;
 	  
-	  $debug and print STDERR "[unary=$unaryop operand=$operand binaryop=$binaryop lo=$binop_leftover, new cstack={".
-	    $self->dump_stack(\@cstack,1)."} ]";
+#	  $debug and print STDERR "[unary=$unaryop operand=$operand binaryop=$binaryop lo=$binop_leftover, new cstack={".
+#	    $self->dump_stack(\@cstack,1)."} ]";
       }
       
       $binop_leftover and push @cstack, [ 5, $binop_leftover ];
@@ -1787,6 +1786,7 @@ sub load_from_file {
     $self->{file_cache}{$fn} and return $self->{file_cache}{$fn};
     $fn =~ s/^[\+<>|]+//;
     $buf = '';
+    `echo .. $fn ..`;
     sysopen(TMPL,$fn,0) || do {
 	$debug and print STDERR "Text::BasicTemplate::load_from_file($fn): $!";
 	return undef;
@@ -1797,7 +1797,6 @@ sub load_from_file {
     }
     $self->{use_flock} and flock(TMPL,LOCK_UN);
     close(TMPL);
-    $buf .= substr($^X,0,0); # deliberately taint the contents
     $self->{use_file_cache} and $self->{file_cache}{$fn} = \$buf;
     \$buf;
 }
@@ -1828,11 +1827,11 @@ sub bt_include {
 	}
 	if ($self->is_tainted($file) &&
 	    !$self->{bt_include_allow_tainted}) {
-	    return "[bt_include: semisecure filename $file is tainted, can't include]";
+	    return "[bt_include: filename $file is tainted, can't include]";
 	}
-	-e $file or return "[bt_include: semisecure file $file does not exist]";
-	-f _ or return "[bt_include: semisecure file $file is not a regular file]";
-	-r _ or return "[bt_include: semisecure file $file not readable]";
+	-e $file or return "[bt_include: file $file does not exist]";
+	-f _ or return "[bt_include: file $file is not a regular file]";
+	-r _ or return "[bt_include: file $file not readable]";
 	$parse and return $self->parse($file,$ovr);
 	$buf = $self->load_from_file($file);
 	print STDERR "[buf=$buf for file=$file]";
@@ -1843,13 +1842,13 @@ sub bt_include {
 	}
 	if ($self->is_tainted($file) &&
 	    !$self->{bt_include_allow_tainted}) {
-	    return "[bt_include: virtual filename $file is tainted, can't include]";
+	    return "[bt_include: filename $file is tainted, can't include]";
 	}
 	$file = ($self->{include_document_root} || $ENV{DOCUMENT_ROOT}) .
 	  '/' . $file;
- 	-e $file or return "[bt_include: virtual file $file does not exist]";
-	-f _ or return "[bt_include: virtual file $file is not a regular file]";
-	-r _ or return "[bt_include: virtual file $file not readable]";
+ 	-e $file or return "[bt_include: file $file does not exist]";
+	-f _ or return "[bt_include: file $file is not a regular file]";
+	-r _ or return "[bt_include: file $file not readable]";
 	$parse and return $self->parse($file,$ovr);
 	$buf = $self->load_from_file($file);
 	return ((ref $buf eq 'SCALAR') ? $$buf : "[bt_include: load_from_file returned nothing]");
@@ -2214,10 +2213,6 @@ __END__
 
 =head1 HISTORY
 
-2.004: Fixed a dumb oversight in test suite where valid comparison
-strings assumed that the iteration order in a hash would be consistent
-and predictable.  Passes make-test under perl5.6 now.
-
 2.0: Major rewrite.  Introduced lexical parsing, nested conditionals,
 list/hash formatting, subroutine references, operator evaluation and
 much other related stuff.
